==> libdatetime-locale-perl_1.16.orig.tar.gz: DateTime-Locale-1.16/share/ln-CG.pl <==
{
  am_pm_abbreviated => [
    "nt\N{U+0254}\N{U+0301}ng\N{U+0254}\N{U+0301}",
    "mp\N{U+00f3}kwa"
  ],
  available_formats => {
    E => "ccc",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "E d",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "G y",
    GyMMM => "G y MMM",
    GyMMMEd => "G y MMM d, E",
    GyMMMd => "G y MMM d",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E d/M",
    MMM => "LLL",
    MMMEd => "E d MMM",
    "MMMMW-count-other" => "'week' W 'of' MMMM",
    MMMMd => "MMMM d",
    MMMd => "d MMM",
    Md => "d/M",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "m:ss",
    y => "y",
    yM => "M/y",
    yMEd => "E d/M/y",
    yMMM => "MMM y",
    yMMMEd => "E d MMM y",
    yMMMM => "y MMMM",
    yMMMd => "d MMM y",
    yMd => "d/M/y",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-other" => "'week' w 'of' y"
  },
  code => "ln-CG",
  date_format_full => "EEEE d MMMM y",
  date_format_long => "d MMMM y",
  date_format_medium => "d MMM y",
  date_format_short => "d/M/y",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "ybo",
    "mbl",
    "mst",
    "min",
    "mtn",
    "mps",
    "eye"
  ],
  day_format_narrow => [
    "y",
    "m",
    "m",
    "m",
    "m",
    "p",
    "e"
  ],
  day_format_wide => [
    "mok\N{U+0254}l\N{U+0254} mwa yambo",
    "mok\N{U+0254}l\N{U+0254} mwa m\N{U+00ed}bal\N{U+00e9}",
    "mok\N{U+0254}l\N{U+0254} mwa m\N{U+00ed}s\N{U+00e1}to",
    "mok\N{U+0254}l\N{U+0254} ya m\N{U+00ed}n\N{U+00e9}i",
    "mok\N{U+0254}l\N{U+0254} ya m\N{U+00ed}t\N{U+00e1}no",
    "mp\N{U+0254}\N{U+0301}s\N{U+0254}",
    "eyenga"
  ],
  day_stand_alone_abbreviated => [
    "ybo",
    "mbl",
    "mst",
    "min",
    "mtn",
    "mps",
    "eye"
  ],
  day_stand_alone_narrow => [
    "y",
    "m",
    "m",
    "m",
    "m",
    "p",
    "e"
  ],
  day_stand_alone_wide => [
    "mok\N{U+0254}l\N{U+0254} mwa yambo",
    "mok\N{U+0254}l\N{U+0254} mwa m\N{U+00ed}bal\N{U+00e9}",
    "mok\N{U+0254}l\N{U+0254} mwa m\N{U+00ed}s\N{U+00e1}to",
    "mok\N{U+0254}l\N{U+0254} ya m\N{U+00ed}n\N{U+00e9}i",
    "mok\N{U+0254}l\N{U+0254} ya m\N{U+00ed}t\N{U+00e1}no",
    "mp\N{U+0254}\N{U+0301}s\N{U+0254}",
    "eyenga"
  ],
  era_abbreviated => [
    "lib\N{U+00f3}so ya",
    "nsima ya Y"
  ],
  era_narrow => [
    "lib\N{U+00f3}so ya",
    "nsima ya Y"
  ],
  era_wide => [
    "Yambo ya Y\N{U+00e9}zu Kr\N{U+00ed}s",
    "Nsima ya Y\N{U+00e9}zu Kr\N{U+00ed}s"
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Lingala",
  month_format_abbreviated => [
    "yan",
    "fbl",
    "msi",
    "apl",
    "mai",
    "yun",
    "yul",
    "agt",
    "stb",
    "\N{U+0254}tb",
    "nvb",
    "dsb"
  ],
  month_format_narrow => [
    "y",
    "f",
    "m",
    "a",
    "m",
    "y",
    "y",
    "a",
    "s",
    "\N{U+0254}",
    "n",
    "d"
  ],
  month_format_wide => [
    "s\N{U+00e1}nz\N{U+00e1} ya yambo",
    "s\N{U+00e1}nz\N{U+00e1} ya m\N{U+00ed}bal\N{U+00e9}",
    "s\N{U+00e1}nz\N{U+00e1} ya m\N{U+00ed}s\N{U+00e1}to",
    "s\N{U+00e1}nz\N{U+00e1} ya m\N{U+00ed}nei",
    "s\N{U+00e1}nz\N{U+00e1} ya m\N{U+00ed}t\N{U+00e1}no",
    "s\N{U+00e1}nz\N{U+00e1} ya mot\N{U+00f3}b\N{U+00e1}",
    "s\N{U+00e1}nz\N{U+00e1} ya nsambo",
    "s\N{U+00e1}nz\N{U+00e1} ya mwambe",
    "s\N{U+00e1}nz\N{U+00e1} ya libwa",
    "s\N{U+00e1}nz\N{U+00e1} ya z\N{U+00f3}mi",
    "s\N{U+00e1}nz\N{U+00e1} ya z\N{U+00f3}mi na m\N{U+0254}\N{U+030c}k\N{U+0254}\N{U+0301}",
    "s\N{U+00e1}nz\N{U+00e1} ya z\N{U+00f3}mi na m\N{U+00ed}bal\N{U+00e9}"
  ],
  month_stand_alone_abbreviated => [
    "yan",
    "fbl",
    "msi",
    "apl",
    "mai",
    "yun",
    "yul",
    "agt",
    "stb",
    "\N{U+0254}tb",
    "nvb",
    "dsb"
  ],
  month_stand_alone_narrow => [
    "y",
    "f",
    "m",
    "a",
    "m",
    "y",
    "y",
    "a",
    "s",
    "\N{U+0254}",
    "n",
    "d"
  ],
  month_stand_alone_wide => [
    "s\N{U+00e1}nz\N{U+00e1} ya yambo",
    "s\N{U+00e1}nz\N{U+00e1} ya m\N{U+00ed}bal\N{U+00e9}",
    "s\N{U+00e1}nz\N{U+00e1} ya m\N{U+00ed}s\N{U+00e1}to",
    "s\N{U+00e1}nz\N{U+00e1} ya m\N{U+00ed}nei",
    "s\N{U+00e1}nz\N{U+00e1} ya m\N{U+00ed}t\N{U+00e1}no",
    "s\N{U+00e1}nz\N{U+00e1} ya mot\N{U+00f3}b\N{U+00e1}",
    "s\N{U+00e1}nz\N{U+00e1} ya nsambo",
    "s\N{U+00e1}nz\N{U+00e1} ya mwambe",
    "s\N{U+00e1}nz\N{U+00e1} ya libwa",
    "s\N{U+00e1}nz\N{U+00e1} ya z\N{U+00f3}mi",
    "s\N{U+00e1}nz\N{U+00e1} ya z\N{U+00f3}mi na m\N{U+0254}\N{U+030c}k\N{U+0254}\N{U+0301}",
    "s\N{U+00e1}nz\N{U+00e1} ya z\N{U+00f3}mi na m\N{U+00ed}bal\N{U+00e9}"
  ],
  name => "Lingala Congo - Brazzaville",
  native_language => "ling\N{U+00e1}la",
  native_name => "ling\N{U+00e1}la Kongo",
  native_script => undef,
  native_territory => "Kongo",
  native_variant => undef,
  quarter_format_abbreviated => [
    "SM1",
    "SM2",
    "SM3",
    "SM4"
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4
  ],
  quarter_format_wide => [
    "s\N{U+00e1}nz\N{U+00e1} m\N{U+00ed}s\N{U+00e1}to ya yambo",
    "s\N{U+00e1}nz\N{U+00e1} m\N{U+00ed}s\N{U+00e1}to ya m\N{U+00ed}bal\N{U+00e9}",
    "s\N{U+00e1}nz\N{U+00e1} m\N{U+00ed}s\N{U+00e1}to ya m\N{U+00ed}s\N{U+00e1}to",
    "s\N{U+00e1}nz\N{U+00e1} m\N{U+00ed}s\N{U+00e1}to ya m\N{U+00ed}nei"
  ],
  quarter_stand_alone_abbreviated => [
    "SM1",
    "SM2",
    "SM3",
    "SM4"
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4
  ],
  quarter_stand_alone_wide => [
    "s\N{U+00e1}nz\N{U+00e1} m\N{U+00ed}s\N{U+00e1}to ya yambo",
    "s\N{U+00e1}nz\N{U+00e1} m\N{U+00ed}s\N{U+00e1}to ya m\N{U+00ed}bal\N{U+00e9}",
    "s\N{U+00e1}nz\N{U+00e1} m\N{U+00ed}s\N{U+00e1}to ya m\N{U+00ed}s\N{U+00e1}to",
    "s\N{U+00e1}nz\N{U+00e1} m\N{U+00ed}s\N{U+00e1}to ya m\N{U+00ed}nei"
  ],
  script => undef,
  territory => "Congo - Brazzaville",
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 31
}

==> libdatetime-locale-perl_1.33.orig.tar.gz: DateTime-Locale-1.33/share/ln-CG.pl <==
{
  am_pm_abbreviated => [
    "nt\N{U+0254}\N{U+0301}ng\N{U+0254}\N{U+0301}",
    "mp\N{U+00f3}kwa",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "E d",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "G y",
    GyMMM => "G y MMM",
    GyMMMEd => "G y MMM d, E",
    GyMMMd => "G y MMM d",
    GyMd => "GGGGG y-MM-dd",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E d/M",
    MMM => "LLL",
    MMMEd => "E d MMM",
    "MMMMW-count-other" => "'week' W 'of' MMMM",
    MMMMd => "MMMM d",
    MMMd => "d MMM",
    Md => "d/M",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "m:ss",
    y => "y",
    yM => "M/y",
    yMEd => "E d/M/y",
    yMMM => "MMM y",
    yMMMEd => "E d MMM y",
    yMMMM => "y MMMM",
    yMMMd => "d MMM y",
    yMd => "d/M/y",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-other" => "'week' w 'of' Y",
  },
  code => "ln-CG",
  date_format_full => "EEEE d MMMM y",
  date_format_long => "d MMMM y",
  date_format_medium => "d MMM y",
  date_format_short => "d/M/y",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "ybo",
    "mbl",
    "mst",
    "min",
    "mtn",
    "mps",
    "eye",
  ],
  day_format_narrow => [
    "y",
    "m",
    "m",
    "m",
    "m",
    "p",
    "e",
  ],
  day_format_wide => [
    "mok\N{U+0254}l\N{U+0254} mwa yambo",
    "mok\N{U+0254}l\N{U+0254} mwa m\N{U+00ed}bal\N{U+00e9}",
    "mok\N{U+0254}l\N{U+0254} mwa m\N{U+00ed}s\N{U+00e1}to",
    "mok\N{U+0254}l\N{U+0254} ya m\N{U+00ed}n\N{U+00e9}i",
    "mok\N{U+0254}l\N{U+0254} ya m\N{U+00ed}t\N{U+00e1}no",
    "mp\N{U+0254}\N{U+0301}s\N{U+0254}",
    "eyenga",
  ],
  day_stand_alone_abbreviated => [
    "ybo",
    "mbl",
    "mst",
    "min",
    "mtn",
    "mps",
    "eye",
  ],
  day_stand_alone_narrow => [
    "y",
    "m",
    "m",
    "m",
    "m",
    "p",
    "e",
  ],
  day_stand_alone_wide => [
    "mok\N{U+0254}l\N{U+0254} mwa yambo",
    "mok\N{U+0254}l\N{U+0254} mwa m\N{U+00ed}bal\N{U+00e9}",
    "mok\N{U+0254}l\N{U+0254} mwa m\N{U+00ed}s\N{U+00e1}to",
    "mok\N{U+0254}l\N{U+0254} ya m\N{U+00ed}n\N{U+00e9}i",
    "mok\N{U+0254}l\N{U+0254} ya m\N{U+00ed}t\N{U+00e1}no",
    "mp\N{U+0254}\N{U+0301}s\N{U+0254}",
    "eyenga",
  ],
  era_abbreviated => [
    "lib\N{U+00f3}so ya",
    "nsima ya Y",
  ],
  era_narrow => [
    "lib\N{U+00f3}so ya",
    "nsima ya Y",
  ],
  era_wide => [
    "Yambo ya Y\N{U+00e9}zu Kr\N{U+00ed}s",
    "Nsima ya Y\N{U+00e9}zu Kr\N{U+00ed}s",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Lingala",
  month_format_abbreviated => [
    "yan",
    "fbl",
    "msi",
    "apl",
    "mai",
    "yun",
    "yul",
    "agt",
    "stb",
    "\N{U+0254}tb",
    "nvb",
    "dsb",
  ],
  month_format_narrow => [
    "y",
    "f",
    "m",
    "a",
    "m",
    "y",
    "y",
    "a",
    "s",
    "\N{U+0254}",
    "n",
    "d",
  ],
  month_format_wide => [
    "s\N{U+00e1}nz\N{U+00e1} ya yambo",
    "s\N{U+00e1}nz\N{U+00e1} ya m\N{U+00ed}bal\N{U+00e9}",
    "s\N{U+00e1}nz\N{U+00e1} ya m\N{U+00ed}s\N{U+00e1}to",
    "s\N{U+00e1}nz\N{U+00e1} ya m\N{U+00ed}nei",
    "s\N{U+00e1}nz\N{U+00e1} ya m\N{U+00ed}t\N{U+00e1}no",
    "s\N{U+00e1}nz\N{U+00e1} ya mot\N{U+00f3}b\N{U+00e1}",
    "s\N{U+00e1}nz\N{U+00e1} ya nsambo",
    "s\N{U+00e1}nz\N{U+00e1} ya mwambe",
    "s\N{U+00e1}nz\N{U+00e1} ya libwa",
    "s\N{U+00e1}nz\N{U+00e1} ya z\N{U+00f3}mi",
    "s\N{U+00e1}nz\N{U+00e1} ya z\N{U+00f3}mi na m\N{U+0254}\N{U+030c}k\N{U+0254}\N{U+0301}",
    "s\N{U+00e1}nz\N{U+00e1} ya z\N{U+00f3}mi na m\N{U+00ed}bal\N{U+00e9}",
  ],
  month_stand_alone_abbreviated => [
    "yan",
    "fbl",
    "msi",
    "apl",
    "mai",
    "yun",
    "yul",
    "agt",
    "stb",
    "\N{U+0254}tb",
    "nvb",
    "dsb",
  ],
  month_stand_alone_narrow => [
    "y",
    "f",
    "m",
    "a",
    "m",
    "y",
    "y",
    "a",
    "s",
    "\N{U+0254}",
    "n",
    "d",
  ],
  month_stand_alone_wide => [
    "s\N{U+00e1}nz\N{U+00e1} ya yambo",
    "s\N{U+00e1}nz\N{U+00e1} ya m\N{U+00ed}bal\N{U+00e9}",
    "s\N{U+00e1}nz\N{U+00e1} ya m\N{U+00ed}s\N{U+00e1}to",
    "s\N{U+00e1}nz\N{U+00e1} ya m\N{U+00ed}nei",
    "s\N{U+00e1}nz\N{U+00e1} ya m\N{U+00ed}t\N{U+00e1}no",
    "s\N{U+00e1}nz\N{U+00e1} ya mot\N{U+00f3}b\N{U+00e1}",
    "s\N{U+00e1}nz\N{U+00e1} ya nsambo",
    "s\N{U+00e1}nz\N{U+00e1} ya mwambe",
    "s\N{U+00e1}nz\N{U+00e1} ya libwa",
    "s\N{U+00e1}nz\N{U+00e1} ya z\N{U+00f3}mi",
    "s\N{U+00e1}nz\N{U+00e1} ya z\N{U+00f3}mi na m\N{U+0254}\N{U+030c}k\N{U+0254}\N{U+0301}",
    "s\N{U+00e1}nz\N{U+00e1} ya z\N{U+00f3}mi na m\N{U+00ed}bal\N{U+00e9}",
  ],
  name => "Lingala Congo - Brazzaville",
  native_language => "ling\N{U+00e1}la",
  native_name => "ling\N{U+00e1}la Kongo",
  native_script => undef,
  native_territory => "Kongo",
  native_variant => undef,
  quarter_format_abbreviated => [
    "SM1",
    "SM2",
    "SM3",
    "SM4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "s\N{U+00e1}nz\N{U+00e1} m\N{U+00ed}s\N{U+00e1}to ya yambo",
    "s\N{U+00e1}nz\N{U+00e1} m\N{U+00ed}s\N{U+00e1}to ya m\N{U+00ed}bal\N{U+00e9}",
    "s\N{U+00e1}nz\N{U+00e1} m\N{U+00ed}s\N{U+00e1}to ya m\N{U+00ed}s\N{U+00e1}to",
    "s\N{U+00e1}nz\N{U+00e1} m\N{U+00ed}s\N{U+00e1}to ya m\N{U+00ed}nei",
  ],
  quarter_stand_alone_abbreviated => [
    "SM1",
    "SM2",
    "SM3",
    "SM4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "s\N{U+00e1}nz\N{U+00e1} m\N{U+00ed}s\N{U+00e1}to ya yambo",
    "s\N{U+00e1}nz\N{U+00e1} m\N{U+00ed}s\N{U+00e1}to ya m\N{U+00ed}bal\N{U+00e9}",
    "s\N{U+00e1}nz\N{U+00e1} m\N{U+00ed}s\N{U+00e1}to ya m\N{U+00ed}s\N{U+00e1}to",
    "s\N{U+00e1}nz\N{U+00e1} m\N{U+00ed}s\N{U+00e1}to ya m\N{U+00ed}nei",
  ],
  script => undef,
  territory => "Congo - Brazzaville",
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 40,
}
